.. image:: https://images.unsplash.com/photo-1581059729226-c493d3086748
  :width: 700
  :alt: Cover Photo

.. image:: https://img.shields.io/pypi/v/gulper.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/gulper/
.. image:: https://github.com/Clivern/Gulper/actions/workflows/ci.yml/badge.svg?branch=main
    :alt: Build Status
    :target: https://github.com/Clivern/Gulper/actions/workflows/ci.yml
.. image:: https://static.pepy.tech/badge/gulper
    :alt: Downloads
    :target: https://pepy.tech/projects/gulper

|

=======
Gulper
=======

A Command Line Tool to Backup and Restore SQLite, MySQL and PostgreSQL.
